@@ -16,7 +16,7 @@ from esy.osmfilter import osm_colors as CC
 def read(PBF_inputfile,JSON_outputfile,TM_World_Borders_file,countrycode='EU', NewPreFilterData=False, 
          CreateElements=False, LoadElements=True,
          CreateCountryCodeForLines=False, LoadCountryCodeForLines=False,
-         length=100,min_length=0, verbose=True,multiprocess=True):
+         length=100,min_length=0,multiprocess=True,verbose=False):
     """ Reads the OSM PipelineNetwork into K_Net Class
     \n.. comments: 
     Call: 
@@ -140,16 +140,14 @@ def read(PBF_inputfile,JSON_outputfile,TM_World_Borders_file,countrycode='EU', N
 #    [Data,Elements] = M_OSM_CreateElements('pipelines',countrycode,PBF_inputfile,
 #                          JSON_outputfile, NewPreFilterData=NewPreFilterData, 
 #                          CreateElements=CreateElements, LoadElements=LoadElements)
-    
     ### Hier zwischenergebnisse speichern
     # min_length=min
     # length=length
-    print(countrycode)
     OSM=M_OSM_convert.RawData2ClassData(Data,Elements,JSON_outputfile,TM_World_Borders_file,
                                         countrycode=countrycode, 
                                         CreateCountryCodeForLines=CreateCountryCodeForLines,
                                         LoadCountryCodeForLines=LoadCountryCodeForLines,
-                                        min_length=min_length,segment_length=length)
+                                        min_length=min_length,segment_length=length,verbose=verbose)
     
 
     return OSM
