@@ -132,7 +132,7 @@ def OSMways2nodes(elements,data,min_length=0):
 
 def RawData2ClassData(Data,elements,  JSON_outputfile, TM_World_Borders_file,countrycode,
                       CreateCountryCodeForLines=False,
-                      LoadCountryCodeForLines=False, min_length=1,segment_length=100):
+                      LoadCountryCodeForLines=False, min_length=1,segment_length=100,verbose=False):
     from . import M_OSM_PipeSegmenting as PS
     Ret_Data           = K_Netze.NetComp_OSM()
 
@@ -158,6 +158,7 @@ def RawData2ClassData(Data,elements,  JSON_outputfile, TM_World_Borders_file,cou
                                  # ,                                 length=lengths[i])
 
         Ret_Data.PipeLines.append(PipeLine)
+    
     print('Count:',i+1)
 
     #here wieder rein
@@ -198,10 +199,12 @@ def RawData2ClassData(Data,elements,  JSON_outputfile, TM_World_Borders_file,cou
         Ret_Data.PipePoints.append(PipePoint)
 
     if CreateCountryCodeForLines==True:
-       OP.Create_Pipelines_CountryCodes(JSON_outputfile, TM_World_Borders_file,Ret_Data, countrycode)
+      
+       OP.Create_Pipelines_CountryCodes(JSON_outputfile, TM_World_Borders_file,Ret_Data, countrycode,verbose=False)
 
     if LoadCountryCodeForLines==True:
         print('---Load Line Countrycodes--')
         OP.Load_Pipelines_Countrycodes(JSON_outputfile, Ret_Data, countrycode)
+
     return Ret_Data
 
